Struct pallet_tips::pallet::Pallet [−][src]
pub struct Pallet<T>(_);Expand description
The pallet implementing the on-chain logic.
Implementations
pub fn report_awesome(
origin: OriginFor<T>,
reason: Vec<u8>,
who: T::AccountId
) -> DispatchResult
pub fn report_awesome(
origin: OriginFor<T>,
reason: Vec<u8>,
who: T::AccountId
) -> DispatchResult
Report something reason that deserves a tip and claim any eventual the finder’s fee.
The dispatch origin for this call must be Signed.
Payment: TipReportDepositBase will be reserved from the origin account, as well as
DataDepositPerByte for each byte in reason.
reason: The reason for, or the thing that deserves, the tip; generally this will be a UTF-8-encoded URL.who: The account which should be credited for the tip.
Emits NewTip if successful.
- Complexity:
O(R)whereRlength ofreason.- encoding and hashing of ‘reason’
- DbReads:
Reasons,Tips - DbWrites:
Reasons,Tips
Retract a prior tip-report from report_awesome, and cancel the process of tipping.
If successful, the original deposit will be unreserved.
The dispatch origin for this call must be Signed and the tip identified by hash
must have been reported by the signing account through report_awesome (and not
through tip_new).
hash: The identity of the open tip for which a tip value is declared. This is formed as the hash of the tuple of the original tipreasonand the beneficiary account ID.
Emits TipRetracted if successful.
- Complexity:
O(1)- Depends on the length of
T::Hashwhich is fixed.
- Depends on the length of
- DbReads:
Tips,origin account - DbWrites:
Reasons,Tips,origin account
Give a tip for something new; no finder’s fee will be taken.
The dispatch origin for this call must be Signed and the signing account must be a
member of the Tippers set.
reason: The reason for, or the thing that deserves, the tip; generally this will be a UTF-8-encoded URL.who: The account which should be credited for the tip.tip_value: The amount of tip that the sender would like to give. The median tip value of active tippers will be given to thewho.
Emits NewTip if successful.
- Complexity:
O(R + T)whereRlength ofreason,Tis the number of tippers.O(T): decodingTippervec of lengthT.Tis charged as upper bound given byContainsLengthBound. The actual cost depends on the implementation ofT::Tippers.O(R): hashing and encoding of reason of lengthR
- DbReads:
Tippers,Reasons - DbWrites:
Reasons,Tips
Declare a tip value for an already-open tip.
The dispatch origin for this call must be Signed and the signing account must be a
member of the Tippers set.
hash: The identity of the open tip for which a tip value is declared. This is formed as the hash of the tuple of the hash of the original tipreasonand the beneficiary account ID.tip_value: The amount of tip that the sender would like to give. The median tip value of active tippers will be given to thewho.
Emits TipClosing if the threshold of tippers has been reached and the countdown period
has started.
-
Complexity:
O(T)whereTis the number of tippers. decodingTippervec of lengthT, insert tip and check closing,Tis charged as upper bound given byContainsLengthBound. The actual cost depends on the implementation ofT::Tippers.Actually weight could be lower as it depends on how many tips are in
OpenTipbut it is weighted as if almost full i.e of lengthT-1. -
DbReads:
Tippers,Tips -
DbWrites:
Tips
Close and payout a tip.
The dispatch origin for this call must be Signed.
The tip identified by hash must have finished its countdown period.
hash: The identity of the open tip for which a tip value is declared. This is formed as the hash of the tuple of the original tipreasonand the beneficiary account ID.
- Complexity:
O(T)whereTis the number of tippers. decodingTippervec of lengthT.Tis charged as upper bound given byContainsLengthBound. The actual cost depends on the implementation ofT::Tippers. - DbReads:
Tips,Tippers,tip finder - DbWrites:
Reasons,Tips,Tippers,tip finder
pub fn tips<KArg>(
k: KArg
) -> Option<OpenTip<T::AccountId, BalanceOf<T>, T::BlockNumber, T::Hash>> where
KArg: EncodeLike<T::Hash>,
pub fn tips<KArg>(
k: KArg
) -> Option<OpenTip<T::AccountId, BalanceOf<T>, T::BlockNumber, T::Hash>> where
KArg: EncodeLike<T::Hash>,
TipsMap that are not yet completed. Keyed by the hash of (reason, who) from the value.
This has the insecure enumerable hash function since the key itself is already
guaranteed to be a secure hash.